#
# spec file for package xviewer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xviewer
Version:        3.4.6
Release:        1.4
Summary:        Fast and functional graphics viewer
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://github.com/linuxmint/xviewer
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(cinnamon-desktop)
BuildRequires:  pkgconfig(exempi-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpeas-1.0)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(xapp)
Requires:       xapps-common
Suggests:       %{name}-plugins

%description
xviewer is a simple graphics viewer for the Cinnamon desktop and
others which uses the gdk-pixbuf library. It can deal with large
images, and zoom and scroll with constant memory usage. Its goals
are simplicity and standards compliance.

%package -n      typelib-1_0-Xviewer-3_0
Summary:        Typelib for %{name}

%description -n  typelib-1_0-Xviewer-3_0
This package provides the typelib for %{name}

%package devel
Summary:        Fast and functional graphics viewer development files
Requires:       typelib-1_0-Xviewer-3_0 = %{version}

%description devel
xviewer is a simple graphics viewer for the Cinnamon desktop and
others which uses the gdk-pixbuf library. It can deal with large
images, and zoom and scroll with constant memory usage. Its goals
are simplicity and standards compliance.

%package doc
Summary:        Html documentation for %{name}
BuildArch:      noarch

%description doc
This package provides the docs for %{name}

%lang_package

%prep
%autosetup

%build
%meson \
  -Dexempi=enabled \
  -Dexif=enabled \
  -Djpeg=enabled \
  -Dlcms=enabled \
  -Drsvg=enabled \
  -Ddocs=true \
  -Ddeprecated_warnings=true
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc AUTHORS README.md MAINTAINERS THANKS
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/{actions,apps}/*.{png,svg}
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/glib-2.0/schemas/org.x.viewer.{enums,gschema}.xml
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/{icons,pixmaps}

%files -n typelib-1_0-Xviewer-3_0
%dir %{_libdir}/xviewer/girepository-1.0
%{_libdir}/%{name}/girepository-1.0/Xviewer-3.0.typelib

%files devel
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{name}/lib%{name}.so
%{_datadir}/%{name}/gir-1.0/Xviewer-3.0.gir
%dir %{_datadir}/%{name}/gir-1.0
%dir %{_libdir}/%{name}

%files doc
%{_datadir}/help/*/%{name}/{,figures/}*.{png,page,xml}
%{_datadir}/gtk-doc/html/xviewer
%dir %{_datadir}/help/*/{%{name},%{name}/figures}

%files lang
%{_datadir}/locale/*/*/*.mo

%changelog
* Mon Aug 12 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 3.4.6:
  * Update translations
- update to 3.4.5:
  * Update translations
- update to 3.4.4:
  * Update translations
- update to 3.4.3:
  * Update translations
- update to 3.4.2:
  * Fix potential infinite while loop and interpreting unsigned int as signed
- update to 3.4.1:
  * Update translations
- update to 3.4.0:
  * Add AVIF and HEIF support
  * Add dark mode support
- update to 3.2.12:
  * Use upper case names for boolean constants (False -> FALSE, True -> TRUE).
    Not all distros support not-upper case variant
- update to 3.2.11:
  * Handle repeated prev/next keys
- update to 3.2.10:
  * Fix Batch Save
- udate to 3.2.9:
  * Update translations
- update to 3.2.8:
  * add missing gio-unix-2.0 dependency
- update to 3.2.7:
  * Add webp support
- update to 3.2.6:
  * Update translations
- update to 3.2.5:
  * Port to meson
  * control: capitalize Xviewer in package desc
  * fix lintian warnings
  * update AppStream metadata
  * Use meson's i18n.merge_file (gettext) ... instead of intltool-merge.
  * add install scripts for non-debian builds
  * remove unused variables
  * fix misleading-indentation warnings
  * fix/add checked type casts
  * move .typelib and .gir dirs into private dir
  * Handle repeated prev and next keys
- update spec file to reflect newer standards and move to the newer meson buildsystem
- remove support for suse_version < 1500
- add new package for the HTML docs
* Sun May  1 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.2.4
  * Update translations
* Tue Dec 28 2021 andy great <andythe_great@pm.me>
- Update to version 3.2.3.
  * Move new symbolic icons to xapp library
* Thu Dec  9 2021 andy great <andythe_great@pm.me>
- Update to version 3.2.2.
  * l10n: Update translations
- Update to version 3.2.1
  * Add fit to width and fit to height (#155)
  * l10n: Update POT
- Update to version 3.2.0
  * Disable dark mode in Xfce
  * help: Reorder shortcuts (#153)
  * zoom: Use CAIRO_FILTER_GOOD while zooming (#147)
  * Refresh when the picture is modified externally (#152)
- Update to version 3.0.2
  * l10n: Update translations
* Thu Jun 17 2021 andy great <andythe_great@pm.me>
- Update to version 3.0.1.
  * l10n: Update translations
* Tue Jun  1 2021 andy great <andythe_great@pm.me>
- Update to version 3.0.0.
  * Fix typos in the Contents page
  * Where a list of multiple files is supplied containing no
    directories, display them in the order it specifies, rather
    than sorting. Replace some unnecessary g_list_length calls.
  * Spacebar Optionally Pauses Slideshow
  * xviewer-preferences-dialog.c: Tweak new labels in preferences,
    fix text alignment.
  * Open svgz files
    (Fixes: https://github.com/linuxmint/xviewer/issues/128)
  * i18n: Don't translate gsettings strings
  * l10n: Update POT
* Thu Jan 14 2021 andy great <andythe_great@pm.me>
- Update to version 2.8.3.
  * xviewer-window.c: Add missing NULL terminator to mimetype
    array.
* Sat Jan  2 2021 andy great <andythe_great@pm.me>
- Update to version 2.8.2.
  * Handle Wrong Extensions
  * BMP 24-bit  Fix (#125)
  * l10n: Update translations
* Sat Dec 26 2020 andy great <andythe_great@pm.me>
- Update to version 2.8.1.
  * l10n: Rename some msgids
  * JPG over 16384 pixels
  * l10n: Update translations
* Tue Dec  8 2020 andy great <andythe_great@pm.me>
- Update to version 2.8.0.
  * Configure Mouse Wheel
  * Make the mouse preferences tab look a bit more consistent with
    the other tabs and other apps.
  * Stop Centering Window
  * Delete Dialog Focus
  * Delete Dialog Focus
  * Add favorites to the file menu.
  * l10n: Update POT
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.6.2
  * translation update
* Mon May 11 2020 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 2.6.0:
  * Commit some files that get altered during the build.
  * Remember Maximized State
  * Get rid of autogenerated garbage, gconf references.
  * Key1 behaviour changes
  * Non auto rotate error
  * Add "View Fullscreen" and "View Slideshow" buttons to toolbar
  * l10n: Update translations
  * UI: Bump minimum window width
  * Toolbar: Use a symbolic icon for diaporama
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.2.0:
  * Add Ctrl+Q shortcut to close window
  * l10n: Update translations
* Fri Mar 15 2019 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 2.0.2:
  * l10n: Update translations
  * Consistent icon usage in all xapps: help-contents (#72)
* Sat May 26 2018 sor.alexei@meowr.ru
- Update to version 1.8.1:
  * Update translations.
* Sat Apr 28 2018 sor.alexei@meowr.ru
- Update to version 1.8.0:
  * EogListStore: Use the CHANGES_DONE_HINT to detect file changes.
  * build: Use cinnamon-desktop instead of gnome-desktop.
  * Fix build with gnome-desktop-3.28 development.
- Remove xviewer-use-cinnamon-desktop.patch: fixed upstream.
* Thu Mar 15 2018 sor.alexei@meowr.ru
- Add xviewer-use-cinnamon-desktop.patch: Use cinnamon-desktop
  instead of gnome-desktop.
* Fri Nov 24 2017 sor.alexei@meowr.ru
- Update to version 1.6.1:
  * Update translations.
* Sat Nov  4 2017 sor.alexei@meowr.ru
- Update to version 1.6.0:
  * Switch zoom buttons in toolbar.
  * fullscreen-toolbar: Fix the slideshow play/pause button icon.
  * Menubar: Change Image menu item to File.
  * Update translations.
- Move the .gir file to the devel package.
* Wed Jun 28 2017 sor.alexei@meowr.ru
- Update to version 1.4.3:
  * Update translations.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 1.4.2:
  * Update translations.
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 1.4.1 (changes since 1.2.2):
  * ui: Replace EggEditable toolbar with a GtkToolbar.
  * xviewer-window: Show/hide the toolbar with a revealer.
  * ui: Switch to using symbolic style icons.
  * fullscreen-toolbar: Update the styling.
  * ui: Don't handle double click events globally for the window.
  * window: Don't hide the sidebar when going fullscreen.
  * l10n: Update POT file.
  * Update translations.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 1.2.2:
  * Update translations.
* Thu Nov 10 2016 sor.alexei@meowr.ru
- Update to version 1.2.1:
  * Update translations.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 1.2.0:
  * Don't show sidebar by default.
  * Move menu item to Accessories category.
  * Fix resampling when picture is zoomed.
  * Add a View->Reload action and remove the Reload plugin.
  * Removed fullscreen and date-in-statusbar plugins.
  * Apply custom background color to fullscreen background.
  * Fix Rotate and Reload using the same shortcut key.
* Fri Jul 15 2016 sor.alexei@meowr.ru
- Update to version 1.0.6:
  * Add Xfce support.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.5:
  * Update translations.
* Wed Jun 22 2016 sor.alexei@meowr.ru
- Update to version 1.0.4:
  * Fix setting background in MATE.
  * Show application name in the about dialog.
* Tue May 24 2016 sor.alexei@meowr.ru
- Update to version 1.0.3:
  * Update translations.
* Wed Apr 27 2016 sor.alexei@meowr.ru
- Update to version 1.0.2:
  * Avoid integer overflow when allocating a large block of memory.
  * Update description and pot file.
  * Update translations.
* Sun Feb  7 2016 sor.alexei@meowr.ru
- Initial package, based on eom's package.
